@@ -3,9 +3,11 @@ import sys
 import threading
 from getopt import getopt
 
+import performance
+
 from performance.android import AndroidApp
 
-from performance import VERSION, android
+from performance import VERSION, android, properties, config
 from performance import android_device
 from performance.android_device import Device
 from performance.config import WORK_DIR
@@ -14,7 +16,7 @@ from performance.log import tip
 
 def usage():
     print("Performance Test Kit")
-    print("usage: ptk [-d device] [-o output] [-s] [-t duration] [-s] [-v] [-h] <app_package_name>")
+    print("usage: ptk [-d device] [-o output] [-t duration] [-p property_file] [-s] [-v] [-h] <app_package_name>")
     print()
     print("-h 打印此帮助")
     print("-d 设备号，可以通过adb devices命令拿到")
@@ -22,6 +24,7 @@ def usage():
     print("-o 数据，日志的输出目录")
     print("-s 停止, 后面需要跟app包名")
     print("-t 时间(h), 可以是整数或者小数作为参数, 比如0.1,0.5,1,2,5,8..., 默认值是10")
+    print("-p 属性文件,默认取 ~/ptk/ptk.properties")
 
 
 def version():
@@ -37,7 +40,7 @@ def main():
 
     hours = 10.0
     try:
-        opts, args = getopt(sys.argv[1:], "d:o:t:shv")
+        opts, args = getopt(sys.argv[1:], "d:o:t:p:shv")
         for op, value in opts:
             if op == '-o':
                 output = value
@@ -53,6 +56,11 @@ def main():
                 hours = float(value)
             elif op == '-s':
                 stop = True
+            elif op == '-p':
+                if not os.path.exists(value):
+                    tip("配置文件不存在: %s " % value)
+                    exit(1)
+                config.ptk_properties = properties.parse(value)
         if len(args) < 1:
             usage()
             exit(1)
@@ -77,6 +85,7 @@ def main():
         tip("检测时长: %s(s)" % str(int(hours * 60 * 60)))
         tip("输出目录: " + output)
         tip("检测设备: " + str(devices))
+        tip("属性配置: " + str(os.path.abspath(config.ptk_properties.file_name)))
         tip("")
 
         if stop:
